{ TTaskbar version 1.0 by AM Software
  Copyright  September 1997 by Alexander Meeder

  I found a 'Tip of the week' provided by Delphi Developer's Journal on Borlands
  website. This tip was submitted by: Albie van der Merwe. I made it to a
  easy to use component.

  You can use this component to hide/show the Windows95 taskbar from within your
  program. Simply by setting the properties and/or call the execute-method.

  properties:
  * ActiveOnLoad (default = true), automatically call execute method when loaded
  * RestoreOnDestoy (default = true), automatically restore taskbar when destroyed
  * Show (default = false), hide=false/show=true Windows taskbar

  method:
  * Execute, gives previous state of taskbar (true=visible/false=hidden)

  Questions, suggestions? Mail me: ameeder@dds.nl
}

unit Taskbar;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs;

type
  TTaskbar = class(TComponent)
  private
    FActiveOnLoad: boolean;
    FRestoreOnDestroy: boolean;
    FShow: boolean;

    procedure SetActiveOnLoad(value: boolean);
    procedure SetRestoreOnDestroy(value: boolean);
    procedure SetShow(value: boolean);
  protected
    procedure Loaded; override;
  public
    constructor Create(AOwner: TComponent); override;
    destructor Destroy; override;
    function Execute: boolean;
  published
    property ActiveOnLoad: boolean read FActiveOnLoad write SetActiveOnLoad default true;
    property RestoreOnDestroy: boolean read FRestoreOnDestroy write SetRestoreOnDestroy default true;
    property Show: boolean read FShow write SetShow default false;
  end;

procedure Register;

implementation

function TTaskbar.Execute: boolean;
const
  wndClass = 'Shell_TrayWnd';
var
  wndHandle : THandle;
begin
  Result := false;
  wndHandle := FindWindow(PChar(wndClass), nil);
  case Show of
    true : Result := ShowWindow(wndHandle, SW_RESTORE);
    false: Result := ShowWindow(wndHandle, SW_HIDE);
  end;
end;

procedure TTaskbar.Loaded;
begin
  inherited Loaded;
  if not (csDesigning in ComponentState) and ActiveOnLoad then Execute;
end;

procedure TTaskbar.SetActiveOnLoad(value: boolean);
begin
  if value <> FActiveOnLoad then FActiveOnLoad := value;
end;

procedure TTaskbar.SetRestoreOnDestroy(value: boolean);
begin
  if value <> FRestoreOnDestroy then FRestoreOnDestroy := value;
end;

procedure TTaskbar.SetShow(value: boolean);
begin
  if value <> FShow then FShow := value;
end;

constructor TTaskbar.Create(AOwner: TComponent);
begin
  inherited Create(AOwner);
  FActiveOnLoad := true;
  FRestoreOnDestroy := true;
  FShow := false;
end;

destructor TTaskbar.Destroy;
begin
  if RestoreOnDestroy then
  begin
    FShow := true;
    Execute;
  end;
  inherited Destroy;
end;

procedure Register;
begin
  RegisterComponents('Samples', [TTaskbar]);
end;

end.
